@@ -1,8 +1,9 @@
 #PK model option
 PK.fit <- function(PKindex)
 {
-  file.menu <- c("One-Compartment PK Models", 
-                 "Two-Compartment PK Models",
+  file.menu <- c("One-Compartment PK Model", 
+                 "Two-Compartment PK Model",
+                 "Three-Compartment PK Model (iv bolus only)",
                  "Macroconstant Exponential Functions",
                  "Go Back One Upper Level")
   pick <- menu(file.menu, title = "<< Selection of a PK Model >>")
@@ -16,9 +17,13 @@ PK.fit <- function(PKindex)
   }
   else if (pick == 3){
      cat("\n\n")
-     macro(PKindex)
+     fbolus3(PKindex)
   }
   else if (pick == 4){
+     cat("\n\n")
+     macro(PKindex)
+  }
+  else if (pick == 5){
      cat("\n\n")
      run()
   }        
