@@ -6,9 +6,9 @@ sbolus2.out<-function(PKtime,kel,k12,k21,Vd,defun,par1,par2,par3,par4,Dose,i,typ
   C1.lsoda<-data.frame(lsoda(c(Dose/Vd,0),c(0,time),defun,parms)) 
   cat("\n\n")
   cat("****************************************************\n")
-  cat("Summary Table                                       \n")
-  cat("Model: 2-Compartment, IV-Bolus, & Single-Dose Model \n") 
-  cat("Error Type:", type,"                                \n\n")
+  cat(" Summary Table                                       \n")
+  cat(" Model: 2-compartment, iv bolus, single-dose model \n") 
+  cat(" Error Type:", type,"                                \n\n")
   sim<-matrix(c(kel,k12,k21,Vd,par1,par2,par3,par4),4,2)
   dimnames(sim)<-list(c("kel","k12","k21","Vd"),c("Value","Selected"))
   show(sim)
