@@ -6,10 +6,10 @@ sfirst2.out<-function(PKtime,ka,kel,k12,k21,Vd,defun,par1,par2,par3,par4,par5,Do
   C1.lsoda<-data.frame(lsoda(c(Dose,0,0),c(0,time),defun,parms,rtol=1e-6,atol=1e-6))
   cat("\n\n")
   cat("*******************************************************\n")
-  cat("Summary Table                                        \n\n")
-  cat("Model: 2-Compartment, Extravascular,                   \n") 
-  cat("       Single-Dose, & 1-Ordered without Lag Time Model \n") 
-  cat("Error Type:", type,"                                 \n\n")
+  cat(" Summary Table                                        \n\n")
+  cat(" Model: 2-compartment, extravascular,                   \n") 
+  cat("        single-dose, & 1st-ordered without lag time model \n") 
+  cat(" Error Type:", type,"                                 \n\n")
   sim<-matrix(c(ka,kel,k12,k21,Vd,par1,par2,par3,par4,par5),5,2)
   dimnames(sim)<-list(c("ka","kel","k12","k21","Vd"),c("Value","Selected"))
   show(sim)
