@@ -6,10 +6,10 @@ sinfu.mm.out<-function(PKtime,Vm,Km,Vd,defun,par1,par2,par3,Dose,i,type)
   C1.lsoda<-data.frame(lsoda(0,c(0,time),defun,parms))    
   cat("\n")
   cat("************************************************\n")
-  cat("Summary Table                                   \n")
-  cat("Model: 1-Compartment, IV-Infusion, Single-Dose, \n") 
-  cat("       & Michaelis-Menten Elimination Model     \n")
-  cat("Error Type:", type,"                            \n\n")
+  cat(" Summary Table                                   \n")
+  cat(" Model: 1-compartment, iv infusion, single-dose, \n") 
+  cat("        & Michaelis-Menten elimination model     \n")
+  cat(" Error Type:", type,"                            \n\n")
   sim<-matrix(c(Vm,Km,Vd,par1,par2,par3),3,2)
   dimnames(sim)<-list(c("Vm","Km","Vd"),c("Value","Selected"))
   show(sim)    
