@@ -1,6 +1,7 @@
 ###Simulation
 ###One compartment PK model iv infusion single dose
 ###optional Michaelis-Menten Elimination
+
 sinfu1 <- function(Subject=NULL,  # N Subj's 
                    PKtime=NULL,   # times for sampling
                    Dose=NULL,     # single dose
@@ -10,99 +11,74 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                    MMe=FALSE, ## michaelis-menten elimination?
                    Vm=NULL,Km=NULL)
 {
+  options(warn=-1)
+  cat("\n First enter all paramaters used for simulation profile.\n");readline(" Press Enter to continue...\n\n")
   
-  #options(warn=-1)
-  
-  if (is.null(Subject) || !is.integer(Subject)) {
-     cat("How many subjects do you want?\n")
-     Subject<-scan(nlines=1,quiet=TRUE)
-  }
-
-  if (is.null(PKtime)) { 
-    ## need to verify is a numeric ordered vector.
-    PKtime<-data.frame(time=c(0))
-    PKtime<-edit(PKtime)
-  }
-  
-  cat("\n")
-  show(PKtime)
-
-  if (is.null(Dose)) {
-    cat("\nEnter dose\n")
-    Dose<-scan(nlines=1,quiet=TRUE)
-  }
-
-  if (is.null(Tinf)) {
-    cat("\nEnter value for infusion time\n")
-    Tinf<-scan(nlines=1,quiet=TRUE)
-    cat("\n")
-  }
-
-  if ( !MMe) { 
-    if (is.null(kel) || is.null(Vd)) {
-       par<-data.frame(Parameter=c("kel","Vd"),Initial=c(0))
-       par<-edit(par)
-       repeat{
-           if ( par[1,2] == 0 || par[2,2] ==0){
-             cat("\n")
-             cat("**********************************\n")
-             cat(" Parameter value can not be zero. \n")
-             cat(" Press Enter to continue.         \n")
-             cat("**********************************\n\n")
-             readline()
-             cat("\n")
-             par<-edit(par)}   
-           else{
-             break
-             return(edit(par))}
-        } 
-        cat("\n")       
-        show(par)
-       
-       
-       cat("\n")
-       par1<-par[1,2]
-       par2<-par[2,2]
-     } 
-     else {
-       par1 <- kel
-       par2 <- Vd
-     } 
+  if (!MMe) { 
+      par<-data.frame(Parameter=c("Total_subject#","Dose","Tinf","kel","Vd"),Initial=c(24,300,1.0,0.31,11.7))
+      par<-edit(par)                                                       
+      repeat{
+          if (par[1,2]<=0 || par[2,2]<=0 || par[3,2]<=0 || par[4,2]<=0|| par[5,2]<=0){
+            cat("\n")
+            cat("**********************************\n")
+            cat(" Any parameter value can not be equal to or less than zero.\n")
+            cat(" Press Enter to continue.         \n")
+            cat("**********************************\n\n")
+            readline()
+            cat("\n")
+            par<-edit(par)}   
+          else{
+            break
+            return(edit(par))}
+       } 
+       cat("\n")       
+       show(par)
+      
+      cat("\n")
+      Subject<-par[1,2]
+      Dose<-par[2,2]
+      Tinf<-par[3,2]
+      par1<-par[4,2]
+      par2<-par[5,2]
+     
   }
   else{
-    if (is.null(Vm) || is.null(Km) || is.null(Vd)){
-       par<-data.frame(Parameter=c("Vm","Km","Vd"),Initial=c(0))
-       par<-edit(par)
-       repeat{
-           if ( par[1,2] == 0 || par[2,2] ==0 || par[3,2]==0){
-             cat("\n")
-             cat("**********************************\n")
-             cat(" Parameter value can not be zero. \n")
-             cat(" Press Enter to continue.         \n")
-             cat("**********************************\n\n")
-             readline()
-             cat("\n")
-             par<-edit(par)}   
-           else{
-             break
-             return(edit(par))}
-        } 
-        cat("\n")       
-        show(par)
-       
-       cat("\n")
-       par1<-par[1,2]
-       par2<-par[2,2]
-       par3<-par[3,2]
-    } 
-    else {
-       par1 <- Vm
-       par2 <- Km
-       par3 <- Vd
-    }
-  } 
+    par<-data.frame(Parameter=c("Total_subject#","Dose","Tinf","Vm","Km","Vd"),Initial=c(24,300,0.5,0.31,4.74,11.7))
+    par<-edit(par)                                                       
+    repeat{
+        if (par[1,2]<=0 || par[2,2]<=0 || par[3,2]<=0 || par[4,2]<=0|| par[5,2]<=0|| par[6,2]<=0){
+          cat("\n")
+          cat("**********************************\n")
+          cat(" Any parameter value can not be equal to or less than zero.\n")
+          cat(" Press Enter to continue.         \n")
+          cat("**********************************\n\n")
+          readline()
+          cat("\n")
+          par<-edit(par)}   
+        else{
+          break
+          return(edit(par))}
+     } 
+     cat("\n")       
+     show(par)
+    
+    cat("\n")
+    Subject<-par[1,2]
+    Dose<-par[2,2]
+    Tinf<-par[3,2]
+    par1<-par[4,2]
+    par2<-par[5,2]
+    par3<-par[6,2]
+}
 
-  if ( ! MMe){
+   readline("\n Next enter time points. Press Enter to continue.\n\n")
+   PKtime<-data.frame(time=c(0))
+   ### PKtime<-data.frame(time=c(0,.1,.2,.3,.4,.5,.6,.8,1,2,4,6,8,12,14,16,18,24))
+   PKtime<-edit(PKtime)
+   cat("\n")
+   show(PKtime);cat("\n\n")
+   
+  if (!MMe){
     defun<- function(time,y,parms) { 
       if(time<=Tinf)         
         dCpdt <- (Dose/Tinf)/parms["Vd"]-parms["kel"]*y[1]
@@ -114,9 +90,9 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
   else{
     defun<- function(time, y, parms) { 
       if(time<=Tinf)  
-        dCpdt <- (Dose/Tinf)/parms["Vd"]-(parms["Vm"]/parms["Vd"])*y[1]/(parms["Km"]/parms["Vd"]+y[1]) 
+        dCpdt <- (Dose/Tinf)/parms["Vd"]-parms["Vm"]*y[1]/(parms["Km"]+y[1]) 
       else
-        dCpdt <- -(parms["Vm"]/parms["Vd"])*y[1]/(parms["Km"]/parms["Vd"]+y[1])
+        dCpdt <- -parms["Vm"]*y[1]/(parms["Km"]+y[1])
       list(dCpdt)
     }
   }   
@@ -141,11 +117,11 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                   "Error = Uniform Error*True Value")
        
        if (pick ==1){
-         PKindex<-vector(Subject,mode="list")
+         PKindex<-vector(Subject,mode="list");cat("\n")
          for( i in 1:Subject)  {
-           cat("\n\n             << Subject",i,">>\n\n" )   
+           cat("\n     << Subject:- #",i,">>\n\n" )
        
-           if (! MMe ){
+           if (!MMe){
              kel<-par1
              Vd<-par2   
              PKindex[[i]]<-sinfu1.out(PKtime,kel,Vd,defun,par1,par2,Dose,i,type) 
@@ -162,44 +138,30 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
          savefile(PKindex)
        }   
        else {
-         if (! MMe){
-           cat("\n\nEnter error factor for kel\n")
-           factor1<-scan(nlines=1,quiet=TRUE)
-           repeat{
-              if ( factor1 == 0 ){
+         if (!MMe){
+            par.err<-data.frame(Parameter=c("kel","Vd"),error_factor=c(.15,.15))
+            par.err<-edit(par.err)
+            repeat{
+            if (par.err[1,2] <=0 || par.err[2,2] <=0){
                 cat("\n")
                 cat("**********************************\n")
-                cat(" Parameter value can not be zero. \n")
+                cat(" Parameter values can be equal or less than zero. \n")
                 cat(" Press Enter to continue.         \n")
                 cat("**********************************\n\n")
                 readline()
                 cat("\n")
-                factor1<-scan(nlines=1,quiet=TRUE)}   
-           else{
+                par.err<-edit(par.err)}   
+              else{
                 break
-                return(factor1)}
-           }
+                return(edit(par.err))}
+            }
+            
+            factor1<-par.err[1,2]
+            factor2<-par.err[2,2]
            
-           cat("\nEnter error factor for Vd\n")
-           factor2<-scan(nlines=1,quiet=TRUE)
-           repeat{
-              if ( factor2 == 0 ){
-                cat("\n")
-                cat("**********************************\n")
-                cat(" Parameter value can not be zero. \n")
-                cat(" Press Enter to continue.         \n")
-                cat("**********************************\n\n")
-                readline()
-                cat("\n")
-                factor2<-scan(nlines=1,quiet=TRUE)}   
-           else{
-                break
-                return(factor2)}
-           }
-           
-           PKindex<-vector(Subject,mode="list")
+           PKindex<-vector(Subject,mode="list");cat("\n")
            for( i in 1:Subject)  {
-             cat("\n\n             << Subject",i,">>\n\n" )  
+             cat("\n     << Subject:- #",i,">>\n\n" )
              switch(pick-1,
                    {kel<-par1+rnorm(1,mean=0,sd=factor1)
                     while(kel<=0){
@@ -233,61 +195,30 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
            }
          }
          else{
-           cat("\n\nEnter error factor for Vm\n")
-           factor1<-scan(nlines=1,quiet=TRUE)
+           par.err<-data.frame(Parameter=c("Vm","Km","Vd"),error_factor=c(.15,.15,.15))
+           par.err<-edit(par.err)
            repeat{
-              if ( factor1 == 0 ){
-                cat("\n")
-                cat("**********************************\n")
-                cat(" Parameter value can not be zero. \n")
-                cat(" Press Enter to continue.         \n")
-                cat("**********************************\n\n")
-                readline()
-                cat("\n")
-                factor1<-scan(nlines=1,quiet=TRUE)}   
-           else{
-                break
-                return(factor1)}
+           if (par.err[1,2] <=0 || par.err[2,2] <=0|| par.err[3,2] <=0){
+               cat("\n")
+               cat("**********************************\n")
+               cat(" Parameter values can be equal or less than zero. \n")
+               cat(" Press Enter to continue.         \n")
+               cat("**********************************\n\n")
+               readline()
+               cat("\n")
+               par.err<-edit(par.err)}   
+             else{
+               break
+               return(edit(par.err))}
            }
            
-           cat("\nEnter error factor for Km\n")
-           factor2<-scan(nlines=1,quiet=TRUE)
-           repeat{
-              if ( factor2 == 0 ){
-                cat("\n")
-                cat("**********************************\n")
-                cat(" Parameter value can not be zero. \n")
-                cat(" Press Enter to continue.         \n")
-                cat("**********************************\n\n")
-                readline()
-                cat("\n")
-                factor2<-scan(nlines=1,quiet=TRUE)}   
-           else{
-                break
-                return(factor2)}
-           }
+           factor1<-par.err[1,2]
+           factor2<-par.err[2,2]
+           factor3<-par.err[3,2]
            
-           cat("\nEnter error factor for Vd\n")
-           factor3<-scan(nlines=1,quiet=TRUE)
-           repeat{
-              if ( factor3 == 0 ){
-                cat("\n")
-                cat("**********************************\n")
-                cat(" Parameter value can not be zero. \n")
-                cat(" Press Enter to continue.         \n")
-                cat("**********************************\n\n")
-                readline()
-                cat("\n")
-                factor3<-scan(nlines=1,quiet=TRUE)}   
-           else{
-                break
-                return(factor3)}
-           }
-           
-           
-           PKindex<-vector(Subject,mode="list")
+           PKindex<-vector(Subject,mode="list");cat("\n")
            for( i in 1:Subject)  {
-           cat("\n\n             << Subject",i,">>\n\n" )  
+           cat("\n     << Subject:- #",i,">>\n\n" )
              switch(pick-1,
                    {Vm<-par1+rnorm(1,mean=0,sd=factor1)
                     while(Vm<=0){
@@ -351,80 +282,80 @@ sinfu1 <- function(Subject=NULL,  # N Subj's
                   "Error = Normal Error*True Value",
                   "Error = Uniform Error*True Value")
      
-     cat("\n\nHow many interations do you want to run?\n")
+     cat("\n\nHow many iterations to run for each subject?\n")
      re<-scan(nlines=1,quiet=TRUE)
      
-       if (! MMe){
-         cat("\nEnter error factor for kel\n")
-         factor1<-scan(nlines=1,quiet=TRUE)
-         repeat{
-              if ( factor1 == 0 ){
-                cat("\n")
-                cat("**********************************\n")
-                cat(" Parameter value can not be zero. \n")
-                cat(" Press Enter to continue.         \n")
-                cat("**********************************\n\n")
-                readline()
-                cat("\n")
-                factor1<-scan(nlines=1,quiet=TRUE)}   
-           else{
-                break
-                return(factor1)}
-           }
-         
-         cat("\nEnter error factor for Vd\n")
-         factor2<-scan(nlines=1,quiet=TRUE)
-         repeat{
-              if ( factor2 == 0 ){
-                cat("\n")
-                cat("**********************************\n")
-                cat(" Parameter value can not be zero. \n")
-                cat(" Press Enter to continue.         \n")
-                cat("**********************************\n\n")
-                readline()
-                cat("\n")
-                factor2<-scan(nlines=1,quiet=TRUE)}   
-           else{
-                break
-                return(factor2)}
-           }
+       if (!MMe){
+          par.err<-data.frame(Parameter=c("kel","Vd"),error_factor=c(.15,.15))
+          par.err<-edit(par.err)
+          repeat{
+          if (par.err[1,2] <=0 || par.err[2,2] <=0){
+              cat("\n")
+              cat("**********************************\n")
+              cat(" Parameter values can be equal or less than zero. \n")
+              cat(" Press Enter to continue.         \n")
+              cat("**********************************\n\n")
+              readline()
+              cat("\n")
+              par.err<-edit(par.err)}   
+            else{
+              break
+              return(edit(par.err))}
+          }
+          
+          factor1<-par.err[1,2]
+          factor2<-par.err[2,2]
          
          cat("\n")
          cat("*******************************************************\n")
-         cat("Summary Table                                          \n")
-         cat("Model: 1-Compartment, IV-Infusion, & Single-Dose Model \n")
-         cat("Subject #:", Subject,"                                 \n")
-         cat("Error Type:", type,"                                   \n")
-         cat("Simulation #:", re,"                                   \n\n")
+         cat(" Summary Table                                          \n")
+         cat(" Model: 1-compartment, iv infusion, single-dose model \n")
+         cat(" Subject #:", Subject,"                                 \n")
+         cat(" Error Type:", type,"                                   \n")
+         cat(" Simulation #:", re,"                                   \n\n")
          sim<-matrix(c(par1,par2,factor1,factor2),2,2)
          dimnames(sim)<-list(c("kel","Vd"),c("Selected","Error factor"))
          show(sim)   
          cat("*******************************************************\n\n")
        }
        else{
-         cat("\nEnter error factor for Vm\n")
-         factor1<-scan(nlines=1,quiet=TRUE)
-         cat("\nEnter error factor for Km\n")
-         factor2<-scan(nlines=1,quiet=TRUE)
-         cat("\nEnter error factor for Vd\n")
-         factor3<-scan(nlines=1,quiet=TRUE)
-         cat("\n")
+         par.err<-data.frame(Parameter=c("Vm","Km","Vd"),error_factor=c(.15,.15,.15))
+         par.err<-edit(par.err)
+         repeat{
+         if (par.err[1,2] <=0 || par.err[2,2] <=0|| par.err[3,2] <=0){
+             cat("\n")
+             cat("**********************************\n")
+             cat(" Parameter values can be equal or less than zero. \n")
+             cat(" Press Enter to continue.         \n")
+             cat("**********************************\n\n")
+             readline()
+             cat("\n")
+             par.err<-edit(par.err)}   
+           else{
+             break
+             return(edit(par.err))}
+         }
+         
+         factor1<-par.err[1,2]
+         factor2<-par.err[2,2]
+         factor3<-par.err[3,2]
+
          cat("************************************************\n")
-         cat("Summary Table                                   \n")
-         cat("Model: 1-Compartment, IV-Infusion, Single-Dose, \n") 
-         cat("       & Michaelis-Menten Elimination Model     \n")
-         cat("Subject #:", Subject,"                          \n")
-         cat("Error Type:", type,"                            \n")
-         cat("Simulation #:", re,"                            \n\n")
+         cat(" Summary Table                                   \n")
+         cat(" Model: 1-compartment, iv infusion, single-dose, \n") 
+         cat("        & Michaelis-Menten elimination model     \n")
+         cat(" Subject #:", Subject,"                          \n")
+         cat(" Error Type:", type,"                            \n")
+         cat(" Simulation #:", re,"                            \n\n")
          sim<-matrix(c(par1,par2,par3,factor1,factor2,factor3),3,2)
          dimnames(sim)<-list(c("Vm","Km","Vd"),c("Selected","Error factor"))
          show(sim)   
          cat("************************************************\n\n")
        }
      
-     PKindex<-vector(Subject,mode="list")
+     PKindex<-vector(Subject,mode="list");cat("\n")
      for( i in 1:Subject)  {
-       cat("\n\n             << Subject",i,">>\n\n" ) 
+       cat("\n     << Subject:- #",i,">>\n\n" )
        C1.lsoda<-list()
 
          for (j in 1:re){
