@@ -6,9 +6,9 @@ sinfu1.out<-function(PKtime,kel,Vd,defun,par1,par2,Dose,i,type)
   C1.lsoda<-data.frame(lsoda(0,c(0,time),defun,parms)) 
   cat("\n")
   cat("*******************************************************\n")
-  cat("Summary Table                                          \n")
-  cat("Model: 1-Compartment, IV-Infusion, & Single-Dose Model \n")
-  cat("Error Type:", type,"                                   \n\n")
+  cat(" Summary Table                                          \n")
+  cat(" Model: 1-compartment, iv infusion, single-dose model \n")
+  cat(" Error Type:", type,"                                   \n\n")
   sim<-matrix(c(kel,Vd,par1,par2),2,2)
   dimnames(sim)<-list(c("kel","Vd"),c("Value","Selected"))
   show(sim)
