@@ -6,10 +6,10 @@ szero.mm.out<-function(PKtime,Tabs,Vm,Km,Vd,defun,par1,par2,par3,par4,Dose,i,typ
   C1.lsoda<-data.frame(lsoda(0,c(0,time), defun, parms))   
   cat("\n\n")
   cat("***************************************************************************\n")
-  cat("Summary Table                                                              \n")
-  cat("Model: 1-Compartment, Extravascular, Single-Dose, Zero-Ordered Absorption, \n") 
-  cat("       & Michaelis-Menten Elimination without Lag Time Model               \n")
-  cat("Error Type:", type,"                                                       \n\n")
+  cat(" Summary Table                                                              \n")
+  cat(" Model: 1-compartment, extravascular, single-dose, zero-ordered absorption, \n") 
+  cat("        & Michaelis-Menten elimination without lag time model               \n")
+  cat(" Error Type:", type,"                                                       \n\n")
   sim<-matrix(c(Tabs,Vm,Km,Vd,par1,par2,par3,par4),4,2)
   dimnames(sim)<-list(c("Tabs","Vm","Km","Vd"),c("Value","Selected"))
   show(sim)
