@@ -6,10 +6,10 @@ szero.out<-function(PKtime,Tabs,kel,Vd,defun,par1,par2,par3,Dose,i,type)
   C1.lsoda<-data.frame(lsoda(0, c(0,time), defun, parms))   
   cat("\n")
   cat("********************************************************\n")
-  cat("Summary Table                                           \n")
-  cat("Model: 1-Compartment, Extravascular, Single-Dose,       \n")
-  cat("       & Zero-Ordered Absorption without Lag Time Model \n")
-  cat("Error Type:", type,"                                    \n\n")
+  cat(" Summary Table                                           \n")
+  cat(" Model: 1-compartment, extravascular, single-dose,       \n")
+  cat("        & zero-ordered absorption without lag time model \n")
+  cat(" Error Type:", type,"                                    \n\n")
   sim<-matrix(c(Tabs,kel,Vd,par1,par2,par3),3,2)
   dimnames(sim)<-list(c("Tabs","kel","Vd"),c("Value","Selected"))
   show(sim)  
